if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/beca7b9e-2b2a-481b-5138-0afbdd41cff7/volume/pymongo_1620214111412/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt